@@ -17,7 +17,6 @@ from ..models import LinearLabelModel as _LinearLabelModel
 from . import _BaseSimulator
 
 
-
 class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
     """Simulator for LinearLabelModels."""
 
@@ -116,9 +115,11 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             return None
         return cast(Array, res.loc[:, compounds].values)
 
-    def _make_legend_labels(self, compound: str, initial_index: int) -> list[str]:
+    def _make_legend_labels(
+        self, prefix: str, compound: str, initial_index: int
+    ) -> list[str]:
         return [
-            f"Pos {i}"
+            f"{prefix}{i}"
             for i in range(
                 initial_index, len(self.model.isotopomers[compound]) + initial_index
             )
@@ -142,6 +143,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
+        legend_prefix: str = "Pos ",
         initial_index: int = 0,
     ) -> Tuple[Figure, Axis]:
         """Plot label distribution of a compound."""
@@ -149,7 +151,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             ylabel = "Relative concentration"
         x = self.get_time()
         y = self.get_label_distribution(compound=compound)
-        legend = self._make_legend_labels(compound, initial_index)
+        legend = self._make_legend_labels(legend_prefix, compound, initial_index)
         if title is None:
             title = compound
         return plot(
@@ -192,6 +194,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
+        legend_prefix: str = "Pos ",
         initial_index: int = 0,
     ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of multiple compounds on a grid."""
@@ -201,8 +204,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             for compound in compounds
         ]
         legend_groups = [
-
-            self._make_legend_labels(compound, initial_index)
+            self._make_legend_labels(legend_prefix, compound, initial_index)
             for compound in compounds
         ]
         if ylabels is None and relative:
@@ -251,6 +253,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
+        legend_prefix: str = "Pos ",
         initial_index: int = 0,
     ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of all compounds on a grid."""
@@ -261,8 +264,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
             for compound in compounds
         ]
         legend_groups = [
-
-            self._make_legend_labels(compound, initial_index)
+            self._make_legend_labels(legend_prefix, compound, initial_index)
             for compound in compounds
         ]
         if ylabels is None and relative:
