@@ -88,7 +88,9 @@ def get_compound_elasticities_array(
 
     Also called epsilon-elasticities. Not in steady state!
     """
-    elasticities = np.full(shape=(len(compounds), len(model.get_rate_names())), fill_value=np.nan)
+    elasticities = np.full(
+        shape=(len(compounds), len(model.get_rate_names())), fill_value=np.nan
+    )
     for i, compound in enumerate(compounds):
         elasticities[i] = get_compound_elasticity(
             model=model,
@@ -162,7 +164,9 @@ def get_parameter_elasticities_array(
 
     Also called pi-elasticities. Not in steady state!
     """
-    elasticities = np.full(shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan)
+    elasticities = np.full(
+        shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan
+    )
     for i, parameter in enumerate(parameters):
         elasticities[i] = get_parameter_elasticity(
             model=model,
@@ -278,7 +282,9 @@ def get_response_coefficients(
     if normalized:
         conc_resp_coef *= y_ss_norm  # type: ignore
         flux_resp_coef *= fluxes_array_norm  # type: ignore
-    return np.atleast_1d(np.squeeze(conc_resp_coef)), np.atleast_1d(np.squeeze(flux_resp_coef))
+    return np.atleast_1d(np.squeeze(conc_resp_coef)), np.atleast_1d(
+        np.squeeze(flux_resp_coef)
+    )
 
 
 def get_response_coefficients_array(
@@ -292,8 +298,12 @@ def get_response_coefficients_array(
     **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Array, Array]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
-    crcs = np.full(shape=(len(parameters), len(model.get_all_compounds())), fill_value=np.nan)
-    frcs = np.full(shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan)
+    crcs = np.full(
+        shape=(len(parameters), len(model.get_all_compounds())), fill_value=np.nan
+    )
+    frcs = np.full(
+        shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan
+    )
     for i, parameter in tqdm(enumerate(parameters), total=len(parameters)):
         crc, frc = get_response_coefficients(
             model=model,
